Welcome to nodestack’s documentation! — nodestack 0.1 documentation

# Welcome to nodestack’s documentation!

Note

This project is under active development.

## Content:

- API
  - `Node`

## Installation:

    (venv) $ git clone https://gitea.lutix.org/ftg/nodestack.git

Source code is hosted on my own instance of gitea.

## Basic Usage:

    import nodestack

    class Person(nodestack.Node):
        pass

    bob = Person('Bob')
    eve = Person('Eve')
    alice = Person('Alice')
    alice_again = Person('Alice') # will raise an error

    # Alice is parent of bob and eve
    alice.add_child(bob)
    alice.add_child(eve)

    alice.pretty_print()

    Alice
      -- Bob
      -- Eve